The following organizations or individuals have contributed to ScanCode:

- Abhigyan Kumar Singh @Abhigyankrsingh
- Abhishek Kumar @Abhishek-Dev09
- Aditya Viki @adityaviki
- Agni Bhattacharyya @PyAgni
- Akanksha Garg @akugarg
- Alex Blekhman @a-tinsmith
- Alexander Gschrei @agschrei
- Armijn Hemmel @armijnhemel
- Armin Tänzer @armintaenzertng
- Arnaud Jeansen @ajeans
- Arnav Mandal @arnav-mandal1234
- Aryan Kenchappagol @aryanxk02
- Avi Aryan @aviaryan
- Aviral Verma @avirlrma
- Ayan Sinha Mahapatra @AyanSinhaMahapatra
- Ayush Jain @aj4ayushjain
- Bruno Oliveira @nicoddemus
- Carmen Bianca Bakker @carmenbianca
- Chaitya Shah @Chaitya62
- Chin-Yeung Li @chinyeungli
- Clement Poulain @FOSS117
- Daniel Eder @daniel-eder
- Dan Kegel @dankegel
- Dennis Clark @DennisClark
- Divyansh Sharma @Divyansh2512
- Duncan Howe @Duncan-Howe
- Felix Kauselmann @selmf
- François Granade @farialima
- Frank Viernau @fviernau
- Gaurang Rao @Gaupeng
- Hanif Ali @hanif-ali
- Horie Issei @is2ei
- James Ward @jamesward
- Jelmer Vernooĳ @jelmer
- Kunal Chhabra @kunalchhabra37
- Jillian Daguil @jdaguil
- Jiri Popelka @jpopelka
- Jiyeong Seok @dd-jy
- Johannes Najjar @joshovi
- Jose Nazario @paralax
- Kevin Ji @KevinJi22
- Lali Akhil Raj @lf32
- Lemo Shi @lemoshi
- Li Ha @linexb
- Mankaran Singh @MankaranSingh
- Marc-Etienne Vargenau @vargenau
- Martin Petkov @MartinPetkov
- Maximilian Huber @maxhbr 
- Michael Herzog @mjherzog
- Michael Rupprecht @michaelrup
- Mike Rombout @mrombout
- Mrinal Paliwal @mnpw
- nexB Inc. @nexB
- Nirmal Sarswat @vivonk
- Nisha Kumar @nishakm
- Nishchith Shetty @inishchith
- Nitish Sharma @nitish81299
- Paul Gier @pgier
- Philippe Ombredanne @pombredanne
- Pi Delport @PiDelport
- Pierre Lapointe @pierrelapointe
- Pierre Tardy @tardyp
- Pranamika Pandey @Pihu1998
- Pratik Dey @Pratikrocks
- Qingmin Duanmu @qduanmu
- Rakesh Balusa @balusarakesh
- Ranvir Singh @singh1114
- Ravi Jain @JRavi2
- Richard Fontana @richardfontana
- Richard Menzies @WizardOhio24
- Ritiek Malhotra @ritiek
- Rohit Potter @rpotter12
- Sankha Das @sankha555
- Saravanan G @SaravananOffl
- Sarita Singh @itssingh
- Savino Sguera @savinos
- Sebastian Roth @ened
- Sebastian Schuberth @sschuberth
- Shankhadeep Dey @Iamshankhadeep
- Sharikzama @ZamaSharik
- Shrijal Acharya @OctoPie23
- Shivam Chauhan @chashiv
- Shivam Sandbhor @sbs2001
- Steven Esser @majurg
- Sushant Gupta @susg
- Thomas Druez @tdruez
- Thomas Steenbergen @tsteenbe
- Thorsten Harter @ThorstenHarter
- Till Jaeger @LeChasseur 
- Tobias Furuholm @furuholm
- Tushar Goel @TG1999
- Tushar Mittal @techytushar
- Tushar Upadhyay @tushar912
- Van Lindberg @VanL
- Vibhu Agarwal @Vibhu-Agarwal
- Viktor Tiulpin @tiulpin
- Vinay Kumar Singh @Vinay0001 
- Virag Umathe @viragumathe5
- Yash D. Saraf @yashdsaraf
- Yash Nisar @yash-nisar
- Yash Sharma @yasharmaster
- Yunus Rahbar @yns88
- Stefano Zacchiroli @zacchiro
